#[non_exhaustive]pub enum CodecError {
Encode(Box<dyn StdError + Send + Sync>),
Decode(Box<dyn StdError + Send + Sync>),
}Expand description
Errors returned by codec implementations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Encode(Box<dyn StdError + Send + Sync>)
The codec failed to encode a Rust value into bytes.
Decode(Box<dyn StdError + Send + Sync>)
The codec failed to decode bytes into a Rust value.